@@ -11,7 +11,19 @@ IO::Async::Loop::AnyEvent2::ElectricBoogaloo - load IO::Async::Loop::AnyEvent
 
 =head1 DESCRIPTION
 
-This module lets you load IO::Async::Loop::AnyEvent with AnyEvent 6.1/6.11.
+This module lets you load L<IO::Async::Loop::AnyEvent> with L<AnyEvent> 6.1/7.
+
+Unfortunately, IO::Async::Loop::AnyEvent currently fails its tests because it's
+being sabotaged by AnyEvent, so you have to force the install (e.g. using
+C<cpan -T IO::Async::Loop::AnyEvent> or C<cpanm --notest IO::Async::Loop::AnyEvent>).
+
+After that, IO::Async::Loop::AnyEvent2::ElectricBoogaloo should install normally.
+
+=head1 NOTES
+
+The code to sabotage IO::Async::Loop::AnyEvent first appeared in AnyEvent 6.1
+(it was not present in AnyEvent 6.02). It was later modified in 6.11, and again
+in AnyEvent 7.0. As of 2016, the code is still there.
 
 =head1 SEE ALSO
 
@@ -23,7 +35,7 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011 Lukas Mai.
+Copyright 2011, 2016 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -33,12 +45,12 @@ See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
-; package IO::Async::Loop::AnyEvent2::ElectricBoogaloo
+package IO::Async::Loop::AnyEvent2::ElectricBoogaloo;
 
 ; use warnings
 ; use strict
 
-; *VERSION = \'0.002'
+; *VERSION = \'0.003'
 
 ; use AnyEvent
     (
@@ -56,6 +68,7 @@ See L<http://dev.perl.org/licenses/> for more information.
             ( $_[0] eq 'fatal'
            && ( $_[1] eq "AnyEvent: IO::Async::Loop::AnyEvent detected - this module is broken by design,\nabuses internals and breaks AnyEvent, will not continue."
              || $_[1] eq "AnyEvent: IO::Async::Loop::AnyEvent detected - that module is broken by\ndesign, abuses internals and breaks AnyEvent - will not continue."
+             || $_[1] eq "IO::Async::Loop::AnyEvent detected - that module is broken by\ndesign, abuses internals and breaks AnyEvent - will not continue."
               )
             )
             { return "no :)"
